summaryrefslogtreecommitdiffstats
path: root/tools/qconfig
diff options
context:
space:
mode:
Diffstat (limited to 'tools/qconfig')
-rw-r--r--tools/qconfig/main.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/qconfig/main.cpp b/tools/qconfig/main.cpp
index 4e46f0de1..9eefed74f 100644
--- a/tools/qconfig/main.cpp
+++ b/tools/qconfig/main.cpp
@@ -185,7 +185,7 @@ public:
TQString id;
ChoiceItem(const TQString& i, TQListViewItem* parent) :
TQCheckListItem(parent,
- i.mid(6), // strip "QT_NO_" as we reverse the logic
+ i.mid(6), // strip "TQT_NO_" as we reverse the logic
CheckBox),
id(i)
{
@@ -402,7 +402,7 @@ void Main::loadFeatures(const TQString& filename)
return;
}
TQTextStream s(&file);
- TQRegExp qt_no_xxx("QT_NO_[A-Z_0-9]*");
+ TQRegExp qt_no_xxx("TQT_NO_[A-Z_0-9]*");
TQStringList sections;
#if 1
@@ -569,7 +569,7 @@ void Main::loadConfig(const TQString& filename)
return;
}
TQTextStream s(&file);
- TQRegExp qt_no_xxx("QT_NO_[A-Z_0-9]*");
+ TQRegExp qt_no_xxx("TQT_NO_[A-Z_0-9]*");
for (TQStringList::Iterator ch = choices.begin(); ch != choices.end(); ++ch) {
item[*ch]->setDefined(FALSE);